@@ -1050,7 +1050,11 @@ makeDataReport <- function(data, output=NULL, render=TRUE,
     writer("\n")
     
     writer("Report generation information:\n")
-    writer(" *  Created by ", whoami::fullname(fallback="Could not determine from system") , " (username: `", whoami::username(fallback="Unknown"),  "`).\n")
+    if (whoami_available()) {
+      writer(" *  Created by: ", whoami::fullname(fallback="Could not determine from system") , " (username: `", whoami::username(fallback="Unknown"),  "`).\n")
+    } else {
+      writer(" *  Created by: Could not determine from system (username: Unknown)\n")
+    }
     writer(" *  Report creation time: ", format(Sys.time(), "%a %b %d %Y %H:%M:%S"),"\n")
     writer(" *  Report was run from directory: `", getwd(),"`\n")
     
